--- loncom/lonnet/perl/lonnet.pm	2001/03/22 15:08:49	1.112
+++ loncom/lonnet/perl/lonnet.pm	2001/03/27 21:50:52	1.118
@@ -93,6 +93,7 @@
 # 3/2 Gerd Kortemeyer
 # 3/15 Scott Harrison
 # 3/19,3/20 Gerd Kortemeyer
+# 3/22,3/27 Scott Harrison
 
 package Apache::lonnet;
 
@@ -1242,22 +1243,25 @@ sub definerole {
 # ---------------- Make a metadata query against the network of library servers
 
 sub metadata_query {
-<<<<<<< lonnet.pm
-    my ($query,$custom)=@_;
-    unless ($custom) {
-	my $reply=&reply("querysend:".&escape($query),'msul3');
-	return $reply;
-    }
-    else {
-	my $reply=&reply("querysend:".&escape($query).':'.
-			 &escape($customquery),'msul3');
-	return $reply;
-    }
-=======
-    my ($query)=@_;
-    # need to put in a loop here and return list
-    my $reply=&reply("querysend:".&escape($query),'msul3');
->>>>>>> 1.111
+    my ($query,$custom,$customshow)=@_;
+    # need to put in a library server loop here and return a hash
+#    for my $server (keys %libserv) {
+    my %rhash;
+    for my $server ('msul3') {
+	unless ($custom or $customshow) {
+	    my $reply=&reply("querysend:".&escape($query),$server);
+	    $rhash{$server}=$reply;
+	    return $reply;
+	}
+	else {
+	    my $reply=&reply("querysend:".&escape($query).':'.
+			     &escape($custom).':'.&escape($customshow),
+			     $server);
+	    $rhash{$server}=$reply;
+	    return $reply;
+	}
+    }
+    return \%rhash;
 }
 
 # ------------------------------------------------------------------ Plain Text